@@ -89,7 +89,7 @@ class Vector():
         """defines the truth value of a Vector
         bool(Vector.null) == False"""
 
-        return set(Vector.components(self)) != {0}
+        return not isclose(Vector.mod(self), 0, abs_tol=1e-09)
 
 
     def __hash__(self, /):
@@ -210,7 +210,7 @@ class Vector():
         returns the result for (self + other)"""
 
         v1, v2 = Vector.components(self), Vector.components(other)
-        return Vector.FromSequence([v1[i] + v2[i] for i in range(3)])
+        return Vector.FromSequence(v1[i] + v2[i] for i in range(3))
 
 
     def __sub__(self, other, /):
@@ -282,7 +282,7 @@ class Vector():
         cosines = [cos(radians(angle)) for angle in (alpha, beta, gamma)]
         total = sum(dc**2 for dc in cosines)
 
-        if not isclose(total, 1):
+        if not isclose(total, 1, abs_tol=1e-09):
             raise ValueError(" ".join((
                 "given angles do not form direction cosines:",
                 "see help(FromAngles) for help on valid angles"
@@ -293,25 +293,30 @@ class Vector():
 
     @classmethod
     def FromSequence(cls, sequence, /):
-        """creates a Vector from the given sequence
-        the sequence must have len(sequence) == 3
+        """creates a Vector from the given sequence / generator
+        the sequence must have len(sequence) == 3 / the generator must yield 3
+        int / float numbers
         valid sequences defined here:
             • (x, y, z)
             • [x, y, z]
             • {'x': x, 'y': y, 'z': z}
             • {'i': x, 'j': y, 'k': z}"""
 
-        if not isinstance(sequence, (dict, list, tuple)):
+        from types import GeneratorType
+
+        if not isinstance(sequence, (dict, list, tuple, GeneratorType)):
             raise TypeError(" ".join((
                 "invalid sequence type for 'Vector':",
                 "see help(FromSequence) for help on valid sequences"
             )))
+        if isinstance(sequence, GeneratorType):
+            sequence = tuple(sequence)
+
         if len(sequence) != 3:
             raise ValueError(" ".join((
                 "len of sequence must be 3:",
                 "see help(FromSequence) for help on valid sequences"
             )))
-
         if isinstance(sequence, dict):
             if set(sequence.keys()) not in ({"x", "y", "z"}, {"i", "j", "k"}):
                 raise KeyError(" ".join((
@@ -568,11 +573,11 @@ class Vector():
 
         Vector.ExceptionVector(self, other)
 
-        result1 = (self.y*other.z - self.z*other.y)
-        result2 = (self.z*other.x - self.x*other.z)
-        result3 = (self.x*other.y - self.y*other.x)
-
-        return Vector.FromSequence([result1, result2, result3])
+        return Vector.FromSequence([
+            (self.y*other.z - self.z*other.y),
+            (self.z*other.x - self.x*other.z),
+            (self.x*other.y - self.y*other.x),
+        ])
 
 
     def scalar_triple(self, value1, value3, /):
@@ -600,11 +605,10 @@ class Vector():
         if k == 1:
             return self
         if not isinstance(k, (int, float)):
-            raise TypeError(" ".join((
-                "invalid operand type for 'k':",
-                "must be 'int' / 'float'"
-            )))
-        return Vector.FromSequence([comp * k for comp in self.tuple])
+            raise TypeError(
+                "invalid operand type for 'k': must be 'int' / 'float'"
+            )
+        return Vector.FromSequence(comp * k for comp in self.tuple)
 
 
     def angle(self, other, /):
@@ -686,7 +690,7 @@ class Vector():
     def isunit(self, /):
         """returns True if the given Vector is a unit Vector, False otherwise"""
 
-        return isclose(Vector.mod(self), 1)
+        return isclose(Vector.mod(self), 1, abs_tol=1e-09)
 
 
     def isinverse(self, other, /):
@@ -694,7 +698,7 @@ class Vector():
         False otherwise"""
 
         Vector.ExceptionVector(self, other)
-        return (self == other.inverse()) or (other == self.inverse())
+        return round(self, 10) == round(other.inverse(), 10)
 
 
     def equalmod(self, other, /):
@@ -708,7 +712,9 @@ class Vector():
         """returns True if the given Vectors are co-planar, False otherwise
         Note: using Vector.null as any of the operands returns True"""
 
-        return not Vector.scalar_triple(self, value2, value3)
+        return isclose(
+            Vector.scalar_triple(self, value2, value3), 0, abs_tol=1e-09
+        )
 
 
     def isparallel(self, other, /):
@@ -724,7 +730,7 @@ class Vector():
         Note: using Vector.null as either of the operands raises Exception"""
 
         Vector.ExceptionNull(self, other)
-        return not self.dot(other)
+        return isclose(self.dot(other), 0, abs_tol=1e-09)
 
 
     def random(*, mod=1):
